@@ -13,7 +13,7 @@ namespace Tomboy.Sync
 		private string serverId;
 
 		private string serverPath;
-		private string notePath;
+		private string cachePath;
 		private string lockPath;
 		private string manifestPath;
 
@@ -32,7 +32,7 @@ namespace Tomboy.Sync
 			if (!Directory.Exists (serverPath))
 				throw new DirectoryNotFoundException (serverPath);
 
-			notePath = Tomboy.DefaultNoteManager.NoteDirectoryPath;
+			cachePath = Services.NativeApplication.CacheDirectory;
 			lockPath = Path.Combine (serverPath, "lock");
 			manifestPath = Path.Combine (serverPath, "manifest.xml");
 
@@ -96,11 +96,16 @@ namespace Tomboy.Sync
 			return noteUUIDs;
 		}
 
+		public bool UpdatesAvailableSince (int revision)
+		{
+			return LatestRevision > revision; // TODO: Mounting, etc?
+		}
+
 		public virtual IDictionary<string, NoteUpdate> GetNoteUpdatesSince (int revision)
 		{
 			Dictionary<string, NoteUpdate> noteUpdates = new Dictionary<string, NoteUpdate> ();
 
-			string tempPath = Path.Combine (notePath, "sync_temp");
+			string tempPath = Path.Combine (cachePath, "sync_temp");
 			if (!Directory.Exists (tempPath)) {
 				Directory.CreateDirectory (tempPath);
 			} else {
@@ -112,7 +117,7 @@ namespace Tomboy.Sync
 				} catch {}
 			}
 
-		if (IsValidXmlFile (manifestPath)) {
+			if (IsValidXmlFile (manifestPath)) {
 				// TODO: Permissions errors
 				using (FileStream fs = new FileStream (manifestPath, FileMode.Open)) {
 					XmlDocument doc = new XmlDocument ();
@@ -237,10 +242,8 @@ namespace Tomboy.Sync
 				}
 
 				// Write out the new manifest file
-				XmlTextWriter xml = new XmlTextWriter (manifestFilePath, System.Text.Encoding.UTF8);
+				XmlWriter xml = XmlWriter.Create (manifestFilePath, XmlEncoder.DocumentSettings);
 				try {
-					xml.Formatting = Formatting.Indented;
-
 					xml.WriteStartDocument ();
 					xml.WriteStartElement (null, "sync", null);
 					xml.WriteAttributeString ("revision", newRevision.ToString ());
@@ -496,10 +499,8 @@ namespace Tomboy.Sync
 
 		private void UpdateLockFile (SyncLockInfo syncLockInfo)
 		{
-			XmlTextWriter xml = new XmlTextWriter (lockPath, System.Text.Encoding.UTF8);
+			XmlWriter xml = XmlWriter.Create (lockPath, XmlEncoder.DocumentSettings);
 			try {
-				xml.Formatting = Formatting.Indented;
-
 				xml.WriteStartDocument ();
 				xml.WriteStartElement (null, "lock", null);
 
